==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Effect/ladspa/ladspabutton.cpp <==
/***************************************************************************
 *   Copyright (C) 2010 by Ilya Kotov                                      *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include "ladspabutton.h"

LADSPAButton::LADSPAButton(LADSPA_Data *value, QWidget *parent) : QCheckBox(parent)
{
    m_value = value;
    setChecked(*value == 1.0);
    connect(this, SIGNAL(clicked (bool)), SLOT(enable(bool)));
}

void LADSPAButton::enable(bool yes)
{
    *m_value = yes ? 1.0 : 0.0;
}

==> qmmp-1.7.0.tar.bz2: qmmp-1.7.0/src/plugins/Effect/ladspa/ladspabutton.cpp <==
/***************************************************************************
 *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include "ladspabutton.h"

LADSPAButton::LADSPAButton(LADSPA_Data *value, QWidget *parent) : QCheckBox(parent)
{
    m_value = value;
    setChecked(*value == 1.0);
    connect(this, &LADSPAButton::clicked, this, &LADSPAButton::enable);
}

void LADSPAButton::enable(bool yes)
{
    *m_value = yes ? 1.0 : 0.0;
}
